{% extends 'base.html' %}
{% block content %}
    <div class="container d-flex flex-column justify-content-center p-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1 class="text-center">All History</h1>
            <div>
              <a href="/">
                Return to Site
              </a>
            </div>
          </div>
        <div class="table-responsive">
            <table class="table table-striped table-bordered table-hover">
                <thead class="thead-light">  
                <tr>
                    <th scope="col">Title</th>
                    <th scope="col">Updated By</th>
                    <th scope="col">Updated At</th>
                </tr>
                </thead>
                <tbody>
                    {% include 'history_list.html' %}
                </tbody>
            </table>
        </div>
    </div>
    <div class="modal fade" id="documentationModal" tabindex="-1" role="dialog" aria-labelledby="documentationModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document" style="max-width: 60%;">
          <div class="modal-content">
            <div class="modal-header">
              <h5 class="modal-title" id="documentationModalLabel"><a href="{% url 'all_documentation' %}">Documentation</a></h5>
              <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close">
                <span aria-hidden="true"></span>
              </button>
            </div>
            <div class="modal-body">

            </div>
          </div>
      </div>
    </div>
{% endblock %}
</body>
</html>