.markdownx {
    display: flex;
}

.markdownx .col-md-6 {
    flex: 1;
}

.markdownx textarea {
    width: 100%;
    height: 300px; /* Adjust height as needed */
}

.markdownx .markdownx-preview {
    border: 1px solid #ddd;
    background-color: #f8f9fa;
    overflow-y: auto;
    height: 300px; /* Match the textarea height */
    padding: 15px;
}