# Generated by Django 5.0 on 2024-01-09 00:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('easy_docs', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documentation',
            name='reference_url',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='historicaldocumentation',
            name='reference_url',
            field=models.CharField(blank=True, db_index=True, max_length=200, null=True),
        ),
    ]
